@@ -57,7 +57,7 @@ function _M:connected()
 	end
 
 	print("[PROFILE] Thread connecting to "..tostring(profilehost).." on ports ", mport, pport)
-	self.sock = socket.connect("profiles.te4.org", mport)
+	self.sock = socket.connect(profilehost, mport)
 	if not self.sock then self:disconnect() return false end
 --	self.sock:settimeout(10)
 	print("[PROFILE] Thread connected to profiles.te4.org")
@@ -71,7 +71,7 @@ end
 --- Connects the second tcp channel to receive data
 function _M:connectedPull()
 	if self.psock then return true end
-	self.psock = socket.connect("profiles.te4.org", pport)
+	self.psock = socket.connect(profilehost, pport)
 	if not self.psock then return false end
 --	self.psock:settimeout(10)
 	print("[PROFILE] Pull socket connected to profiles.te4.org")
@@ -616,11 +616,12 @@ function _M:orderEntityInfos(o)
 end
 
 function _M:orderEntityPoke(o)
-	self:command("EVLT", "POKE", o.desc:len(), o.data:len(), o.module, o.kind, o.name)
+	self:command("EVLT", "POKE2", o.desc:len(), o.data:len(), o.module, o.kind, o.name)
 	if not self:read("200") then return cprofile.pushEvent(("e='EntityPoke' ok=false err=%q"):format(self.last_error)) end
 	self.sock:send(o.desc)
 	if not self:read("200") then return cprofile.pushEvent("e='EntityPoke' ok=false err='unknown reason'") end
 	self.sock:send(o.data)
+	if not self:read("200") then return cprofile.pushEvent(("e='EntityPoke' ok=false err='%q'"):format(self.last_error)) end
 	cprofile.pushEvent("e='EntityPoke' ok=true")
 end
 
